# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGPClient, AsyncSGPClient
from tests.utils import assert_matches_type
from scale_gp.pagination import SyncPageResponse, AsyncPageResponse
from scale_gp.types.knowledge_bases import (
    UploadListResponse,
    KnowledgeBaseUpload,
    CancelKnowledgeBaseUploadResponse,
    CreateKnowledgeBaseUploadResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUploads:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create_overload_1(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
                "s3_prefix": "s3_prefix",
            },
            chunking_strategy_config={
                "strategy": "character",
                "chunk_overlap": 0,
                "chunk_size": 1,
                "separator": "separator",
            },
            data_source_auth_config={
                "client_secret": "client_secret",
                "source": "SharePoint",
                "encrypted": True,
            },
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_create_overload_1(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_1(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_overload_1(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                data_source_config={
                    "aws_account_id": "aws_account_id",
                    "aws_region": "aws_region",
                    "s3_bucket": "s3_bucket",
                    "source": "S3",
                },
            )

    @parametrize
    def test_method_create_overload_2(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
                "deduplication_strategy": "Overwrite",
            },
            chunks=[
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
            ],
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_create_overload_2(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_2(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_overload_2(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                data_source_config={
                    "artifact_name": "artifact_name",
                    "artifact_uri": "artifact_uri",
                    "source": "LocalChunks",
                },
            )

    @parametrize
    def test_method_create_overload_3(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_3(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={
                "strategy": "character",
                "chunk_overlap": 0,
                "chunk_size": 1,
                "separator": "separator",
            },
            data_source_id="data_source_id",
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_create_overload_3(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_3(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_overload_3(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                chunking_strategy_config={"strategy": "character"},
                data_source_id="data_source_id",
            )

    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    def test_method_retrieve_with_all_params(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
            include_artifact_list=True,
        )
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.retrieve(
                upload_id="upload_id",
                knowledge_base_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upload_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.retrieve(
                upload_id="",
                knowledge_base_id="knowledge_base_id",
            )

    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.list(
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(SyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.list(
            knowledge_base_id="knowledge_base_id",
            limit=1,
            page=1,
            status="Running",
        )
        assert_matches_type(SyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.list(
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(SyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.list(
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(SyncPageResponse[UploadListResponse], upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.list(
                knowledge_base_id="",
            )

    @parametrize
    def test_method_cancel(self, client: SGPClient) -> None:
        upload = client.knowledge_bases.uploads.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_raw_response_cancel(self, client: SGPClient) -> None:
        response = client.knowledge_bases.uploads.with_raw_response.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = response.parse()
        assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    def test_streaming_response_cancel(self, client: SGPClient) -> None:
        with client.knowledge_bases.uploads.with_streaming_response.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = response.parse()
            assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_cancel(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.cancel(
                upload_id="upload_id",
                knowledge_base_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upload_id` but received ''"):
            client.knowledge_bases.uploads.with_raw_response.cancel(
                upload_id="",
                knowledge_base_id="knowledge_base_id",
            )


class TestAsyncUploads:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
                "s3_prefix": "s3_prefix",
            },
            chunking_strategy_config={
                "strategy": "character",
                "chunk_overlap": 0,
                "chunk_size": 1,
                "separator": "separator",
            },
            data_source_auth_config={
                "client_secret": "client_secret",
                "source": "SharePoint",
                "encrypted": True,
            },
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "aws_account_id": "aws_account_id",
                "aws_region": "aws_region",
                "s3_bucket": "s3_bucket",
                "source": "S3",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                data_source_config={
                    "aws_account_id": "aws_account_id",
                    "aws_region": "aws_region",
                    "s3_bucket": "s3_bucket",
                    "source": "S3",
                },
            )

    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
                "deduplication_strategy": "Overwrite",
            },
            chunks=[
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
                {
                    "chunk_position": 0,
                    "text": "text",
                    "metadata": {},
                },
            ],
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            data_source_config={
                "artifact_name": "artifact_name",
                "artifact_uri": "artifact_uri",
                "source": "LocalChunks",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                data_source_config={
                    "artifact_name": "artifact_name",
                    "artifact_uri": "artifact_uri",
                    "source": "LocalChunks",
                },
            )

    @parametrize
    async def test_method_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_3(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={
                "strategy": "character",
                "chunk_overlap": 0,
                "chunk_size": 1,
                "separator": "separator",
            },
            data_source_id="data_source_id",
            force_reupload=True,
        )
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.create(
            knowledge_base_id="knowledge_base_id",
            chunking_strategy_config={"strategy": "character"},
            data_source_id="data_source_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(CreateKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.create(
                knowledge_base_id="",
                chunking_strategy_config={"strategy": "character"},
                data_source_id="data_source_id",
            )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
            include_artifact_list=True,
        )
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.retrieve(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(KnowledgeBaseUpload, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.retrieve(
                upload_id="upload_id",
                knowledge_base_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upload_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.retrieve(
                upload_id="",
                knowledge_base_id="knowledge_base_id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.list(
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(AsyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.list(
            knowledge_base_id="knowledge_base_id",
            limit=1,
            page=1,
            status="Running",
        )
        assert_matches_type(AsyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.list(
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(AsyncPageResponse[UploadListResponse], upload, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.list(
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(AsyncPageResponse[UploadListResponse], upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.list(
                knowledge_base_id="",
            )

    @parametrize
    async def test_method_cancel(self, async_client: AsyncSGPClient) -> None:
        upload = await async_client.knowledge_bases.uploads.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )
        assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_raw_response_cancel(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.knowledge_bases.uploads.with_raw_response.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upload = await response.parse()
        assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

    @parametrize
    async def test_streaming_response_cancel(self, async_client: AsyncSGPClient) -> None:
        async with async_client.knowledge_bases.uploads.with_streaming_response.cancel(
            upload_id="upload_id",
            knowledge_base_id="knowledge_base_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upload = await response.parse()
            assert_matches_type(CancelKnowledgeBaseUploadResponse, upload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_cancel(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `knowledge_base_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.cancel(
                upload_id="upload_id",
                knowledge_base_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upload_id` but received ''"):
            await async_client.knowledge_bases.uploads.with_raw_response.cancel(
                upload_id="",
                knowledge_base_id="knowledge_base_id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["DeploymentExecuteParams"]


class DeploymentExecuteParams(TypedDict, total=False):
    model_instance_id: Required[str]

    stream: bool
    """Flag indicating whether to stream the completion response"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Literal, Required, TypeAlias, TypedDict

from .annotation_config_param import AnnotationConfigParam
from .multiturn_annotation_config_param import MultiturnAnnotationConfigParam
from .summarization_annotation_config_param import SummarizationAnnotationConfigParam

__all__ = [
    "EvaluationUpdateParams",
    "PartialPatchEvaluationRequest",
    "PartialPatchEvaluationRequestAnnotationConfig",
    "RestoreRequest",
]


class PartialPatchEvaluationRequest(TypedDict, total=False):
    annotation_config: PartialPatchEvaluationRequestAnnotationConfig
    """Annotation configuration for tasking"""

    application_spec_id: str

    application_variant_id: str

    description: str

    evaluation_config: object

    evaluation_config_id: str
    """The ID of the associated evaluation config."""

    evaluation_type: Literal["llm_benchmark"]
    """
    If llm_benchmark is provided, the evaluation will be updated to a hybrid
    evaluation. No-op on existing hybrid evaluations, and not available for studio
    evaluations.
    """

    name: str

    question_id_to_annotation_config: Dict[str, AnnotationConfigParam]
    """Specifies the annotation configuration to use for specific questions."""

    restore: Literal[False]
    """Set to true to restore the entity from the database."""

    tags: object


PartialPatchEvaluationRequestAnnotationConfig: TypeAlias = Union[
    AnnotationConfigParam, MultiturnAnnotationConfigParam, SummarizationAnnotationConfigParam
]


class RestoreRequest(TypedDict, total=False):
    restore: Required[Literal[True]]
    """Set to true to restore the entity from the database."""


EvaluationUpdateParams: TypeAlias = Union[PartialPatchEvaluationRequest, RestoreRequest]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGPClient, AsyncSGPClient
from tests.utils import assert_matches_type
from scale_gp.types import (
    Task,
    Evaluation,
    EvaluationWithViews,
)
from scale_gp.pagination import SyncPageResponse, AsyncPageResponse
from scale_gp.types.shared import GenericDeleteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvaluations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_create_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            evaluation_dataset_version=0,
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            tags={},
            type="builder",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_create_overload_1(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_create_overload_1(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_create_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            application_variant_id="application_variant_id",
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            tags={},
            type="default",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_create_overload_2(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_create_overload_2(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_retrieve_with_all_params(self, client: SGPClient) -> None:
        evaluation = client.evaluations.retrieve(
            evaluation_id="evaluation_id",
            view=["ApplicationSpec", "AsyncJobs", "EvaluationConfig"],
        )
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.retrieve(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.retrieve(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.retrieve(
                evaluation_id="",
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_update_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_update_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            evaluation_type="llm_benchmark",
            name="name",
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            restore=False,
            tags={},
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_update_overload_1(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_update_overload_1(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_path_params_update_overload_1(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.update(
                evaluation_id="",
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_update_overload_2(self, client: SGPClient) -> None:
        evaluation = client.evaluations.update(
            evaluation_id="evaluation_id",
            restore=True,
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_update_overload_2(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_update_overload_2(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_path_params_update_overload_2(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.update(
                evaluation_id="",
                restore=True,
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        evaluation = client.evaluations.list()
        assert_matches_type(SyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        evaluation = client.evaluations.list(
            account_id="account_id",
            application_spec_id=0,
            include_archived=True,
            limit=1,
            page=1,
            sort_by=["status:asc", "status:desc", "application_spec_id:asc"],
            view=["ApplicationSpec", "AsyncJobs", "EvaluationConfig"],
        )
        assert_matches_type(SyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(SyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(SyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_method_delete(self, client: SGPClient) -> None:
        evaluation = client.evaluations.delete(
            "evaluation_id",
        )
        assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_raw_response_delete(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.delete(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_streaming_response_delete(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.delete(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    def test_path_params_delete(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_claim_task(self, client: SGPClient) -> None:
        evaluation = client.evaluations.claim_task(
            "evaluation_id",
        )
        assert_matches_type(Task, evaluation, path=["response"])

    @parametrize
    def test_raw_response_claim_task(self, client: SGPClient) -> None:
        response = client.evaluations.with_raw_response.claim_task(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = response.parse()
        assert_matches_type(Task, evaluation, path=["response"])

    @parametrize
    def test_streaming_response_claim_task(self, client: SGPClient) -> None:
        with client.evaluations.with_streaming_response.claim_task(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = response.parse()
            assert_matches_type(Task, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_claim_task(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.evaluations.with_raw_response.claim_task(
                "",
            )


class TestAsyncEvaluations:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            evaluation_dataset_version=0,
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            tags={},
            type="builder",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            application_variant_id="application_variant_id",
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            tags={},
            type="default",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.create(
            account_id="account_id",
            application_spec_id="application_spec_id",
            description="description",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.retrieve(
            evaluation_id="evaluation_id",
            view=["ApplicationSpec", "AsyncJobs", "EvaluationConfig"],
        )
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.retrieve(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.retrieve(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(EvaluationWithViews, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.retrieve(
                evaluation_id="",
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_update_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
            annotation_config={
                "components": [
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                    [
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                        {
                            "data_loc": ["string", "string", "string"],
                            "label": "label",
                        },
                    ],
                ],
                "annotation_config_type": "flexible",
                "direction": "col",
            },
            application_spec_id="application_spec_id",
            application_variant_id="application_variant_id",
            description="description",
            evaluation_config={},
            evaluation_config_id="evaluation_config_id",
            evaluation_type="llm_benchmark",
            name="name",
            question_id_to_annotation_config={
                "foo": {
                    "components": [
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                        [
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                            {
                                "data_loc": ["string", "string", "string"],
                                "label": "label",
                            },
                        ],
                    ],
                    "annotation_config_type": "flexible",
                    "direction": "col",
                }
            },
            restore=False,
            tags={},
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_path_params_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.update(
                evaluation_id="",
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.update(
            evaluation_id="evaluation_id",
            restore=True,
        )
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Evaluation, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.update(
            evaluation_id="evaluation_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Evaluation, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_path_params_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.update(
                evaluation_id="",
                restore=True,
            )

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.list()
        assert_matches_type(AsyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.list(
            account_id="account_id",
            application_spec_id=0,
            include_archived=True,
            limit=1,
            page=1,
            sort_by=["status:asc", "status:desc", "application_spec_id:asc"],
            view=["ApplicationSpec", "AsyncJobs", "EvaluationConfig"],
        )
        assert_matches_type(AsyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(AsyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(AsyncPageResponse[EvaluationWithViews], evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_method_delete(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.delete(
            "evaluation_id",
        )
        assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.delete(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.delete(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(GenericDeleteResponse, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="question_id_to_annotation_config response body fails validation")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_claim_task(self, async_client: AsyncSGPClient) -> None:
        evaluation = await async_client.evaluations.claim_task(
            "evaluation_id",
        )
        assert_matches_type(Task, evaluation, path=["response"])

    @parametrize
    async def test_raw_response_claim_task(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluations.with_raw_response.claim_task(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation = await response.parse()
        assert_matches_type(Task, evaluation, path=["response"])

    @parametrize
    async def test_streaming_response_claim_task(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluations.with_streaming_response.claim_task(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation = await response.parse()
            assert_matches_type(Task, evaluation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_claim_task(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.evaluations.with_raw_response.claim_task(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGPClient, AsyncSGPClient
from tests.utils import assert_matches_type
from scale_gp.types import (
    EvaluationDataset,
    PublishEvaluationDatasetDraftResponse,
    AutoGeneratedDraftTestCaseApproveBatchResponse,
)
from scale_gp.pagination import SyncPageResponse, AsyncPageResponse
from scale_gp.types.shared import GenericDeleteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvaluationDatasets:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create_overload_1(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
            type="manual",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_create_overload_1(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_1(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_overload_2(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
            type="autogenerated",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_create_overload_2(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_2(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_overload_3(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_3(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
            type="safety",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_create_overload_3(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_3(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.retrieve(
            "evaluation_dataset_id",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.retrieve(
            "evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.retrieve(
            "evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update_overload_1(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_update_with_all_params_overload_1(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
            restore=False,
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_update_overload_1(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_1(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_1(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.update(
                evaluation_dataset_id="",
                name="name",
            )

    @parametrize
    def test_method_update_overload_2(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_update_overload_2(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_2(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_2(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.update(
                evaluation_dataset_id="",
                restore=True,
            )

    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.list()
        assert_matches_type(SyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.list(
            account_id="account_id",
            include_archived=True,
            limit=1,
            page=1,
        )
        assert_matches_type(SyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(SyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(SyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_approve_batch(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_approve_batch_with_all_params(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
            force=True,
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_approve_batch(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_approve_batch(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_approve_batch(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.approve_batch(
                evaluation_dataset_id="",
                autogenerated_draft_test_cases=["string", "string", "string"],
            )

    @parametrize
    def test_method_publish(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_publish_with_all_params(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.publish(
            evaluation_dataset_id="evaluation_dataset_id",
            force=True,
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_publish(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_publish(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_publish(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.publish(
                evaluation_dataset_id="",
            )

    @parametrize
    def test_method_remove(self, client: SGPClient) -> None:
        evaluation_dataset = client.evaluation_datasets.remove(
            "evaluation_dataset_id",
        )
        assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_remove(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.with_raw_response.remove(
            "evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_remove(self, client: SGPClient) -> None:
        with client.evaluation_datasets.with_streaming_response.remove(
            "evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_remove(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.remove(
                "",
            )


class TestAsyncEvaluationDatasets:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
            type="manual",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
            type="autogenerated",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            knowledge_base_id="knowledge_base_id",
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_3(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
            type="safety",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_3(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.create(
            account_id="account_id",
            advanced_config={"foo": ["string", "string", "string"]},
            harms_list=["string", "string", "string"],
            name="name",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.retrieve(
            "evaluation_dataset_id",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.retrieve(
            "evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.retrieve(
            "evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_update_with_all_params_overload_1(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
            restore=False,
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_1(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.update(
                evaluation_dataset_id="",
                name="name",
            )

    @parametrize
    async def test_method_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        )
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.update(
            evaluation_dataset_id="evaluation_dataset_id",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_2(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.update(
                evaluation_dataset_id="",
                restore=True,
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.list()
        assert_matches_type(AsyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.list(
            account_id="account_id",
            include_archived=True,
            limit=1,
            page=1,
        )
        assert_matches_type(AsyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(AsyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(AsyncPageResponse[EvaluationDataset], evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_approve_batch(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_approve_batch_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
            force=True,
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_approve_batch(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_approve_batch(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.approve_batch(
            evaluation_dataset_id="evaluation_dataset_id",
            autogenerated_draft_test_cases=["string", "string", "string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_approve_batch(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.approve_batch(
                evaluation_dataset_id="",
                autogenerated_draft_test_cases=["string", "string", "string"],
            )

    @parametrize
    async def test_method_publish(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_publish_with_all_params(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.publish(
            evaluation_dataset_id="evaluation_dataset_id",
            force=True,
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_publish(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_publish(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.publish(
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_publish(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.publish(
                evaluation_dataset_id="",
            )

    @parametrize
    async def test_method_remove(self, async_client: AsyncSGPClient) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.remove(
            "evaluation_dataset_id",
        )
        assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_remove(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.remove(
            "evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_remove(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.remove(
            "evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(GenericDeleteResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_remove(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.remove(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Annotated, TypeAlias

from .._utils import PropertyInfo
from .._models import BaseModel
from .s3_data_source_config import S3DataSourceConfig
from .local_file_source_config import LocalFileSourceConfig
from .slack_data_source_config import SlackDataSourceConfig
from .local_chunks_source_config import LocalChunksSourceConfig
from .confluence_data_source_config import ConfluenceDataSourceConfig
from .share_point_data_source_config import SharePointDataSourceConfig
from .token_chunking_strategy_config import TokenChunkingStrategyConfig
from .custom_chunking_strategy_config import CustomChunkingStrategyConfig
from .google_drive_data_source_config import GoogleDriveDataSourceConfig
from .character_chunking_strategy_config import CharacterChunkingStrategyConfig
from .azure_blob_storage_data_source_config import AzureBlobStorageDataSourceConfig

__all__ = ["PaginatedKnowledgeBaseUploads", "Item", "ItemDataSourceConfig", "ItemChunkingStrategyConfig"]

ItemDataSourceConfig: TypeAlias = Annotated[
    Union[
        S3DataSourceConfig,
        SharePointDataSourceConfig,
        GoogleDriveDataSourceConfig,
        AzureBlobStorageDataSourceConfig,
        LocalChunksSourceConfig,
        LocalFileSourceConfig,
        ConfluenceDataSourceConfig,
        SlackDataSourceConfig,
    ],
    PropertyInfo(discriminator="source"),
]

ItemChunkingStrategyConfig: TypeAlias = Annotated[
    Union[CharacterChunkingStrategyConfig, TokenChunkingStrategyConfig, CustomChunkingStrategyConfig],
    PropertyInfo(discriminator="strategy"),
]


class Item(BaseModel):
    id: str

    data_source_config: ItemDataSourceConfig

    knowledge_base_id: str

    chunking_strategy_config: Optional[ItemChunkingStrategyConfig] = None

    created_at: Union[str, datetime, None] = None

    created_by_schedule_id: Optional[str] = None

    data_source_idempotency_key: Optional[str] = None

    status: Optional[str] = None

    status_reason: Optional[str] = None

    updated_at: Union[str, datetime, None] = None


class PaginatedKnowledgeBaseUploads(BaseModel):
    current_page: int
    """The current page number."""

    items: List[Item]
    """The data returned for the current page."""

    items_per_page: int
    """The number of items per page."""

    total_item_count: int
    """The total number of items of the query"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ChatThreadUpdateParams"]


class ChatThreadUpdateParams(TypedDict, total=False):
    archived_at: str
    """Date when the chat thread is archived, or None to un-archive."""

    title: str
    """The title of the chat thread."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGPClient, AsyncSGPClient
from tests.utils import assert_matches_type
from scale_gp.types import FineTuningJob
from scale_gp.pagination import SyncPageResponse, AsyncPageResponse
from scale_gp.types.shared import GenericDeleteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFineTuningJobs:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
            base_model_id="base_model_id",
            fine_tuned_model_id="fine_tuned_model_id",
            validation_dataset_id="validation_dataset_id",
            vendor_configuration={
                "hyperparameters": {},
                "output": "output",
                "suffix": "suffix",
                "vendor": "LAUNCH",
                "wandb_config": {},
            },
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: SGPClient) -> None:
        response = client.fine_tuning_jobs.with_raw_response.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = response.parse()
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: SGPClient) -> None:
        with client.fine_tuning_jobs.with_streaming_response.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = response.parse()
            assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.retrieve(
            "fine_tuning_job_id",
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.fine_tuning_jobs.with_raw_response.retrieve(
            "fine_tuning_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = response.parse()
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.fine_tuning_jobs.with_streaming_response.retrieve(
            "fine_tuning_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = response.parse()
            assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `fine_tuning_job_id` but received ''"):
            client.fine_tuning_jobs.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.list()
        assert_matches_type(SyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.list(
            account_id="account_id",
            limit=1,
            page=1,
        )
        assert_matches_type(SyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.fine_tuning_jobs.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = response.parse()
        assert_matches_type(SyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.fine_tuning_jobs.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = response.parse()
            assert_matches_type(SyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: SGPClient) -> None:
        fine_tuning_job = client.fine_tuning_jobs.delete(
            "fine_tuning_job_id",
        )
        assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: SGPClient) -> None:
        response = client.fine_tuning_jobs.with_raw_response.delete(
            "fine_tuning_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = response.parse()
        assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: SGPClient) -> None:
        with client.fine_tuning_jobs.with_streaming_response.delete(
            "fine_tuning_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = response.parse()
            assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `fine_tuning_job_id` but received ''"):
            client.fine_tuning_jobs.with_raw_response.delete(
                "",
            )


class TestAsyncFineTuningJobs:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
            base_model_id="base_model_id",
            fine_tuned_model_id="fine_tuned_model_id",
            validation_dataset_id="validation_dataset_id",
            vendor_configuration={
                "hyperparameters": {},
                "output": "output",
                "suffix": "suffix",
                "vendor": "LAUNCH",
                "wandb_config": {},
            },
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.fine_tuning_jobs.with_raw_response.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = await response.parse()
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncSGPClient) -> None:
        async with async_client.fine_tuning_jobs.with_streaming_response.create(
            account_id="account_id",
            training_dataset_id="training_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = await response.parse()
            assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.retrieve(
            "fine_tuning_job_id",
        )
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.fine_tuning_jobs.with_raw_response.retrieve(
            "fine_tuning_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = await response.parse()
        assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.fine_tuning_jobs.with_streaming_response.retrieve(
            "fine_tuning_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = await response.parse()
            assert_matches_type(FineTuningJob, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `fine_tuning_job_id` but received ''"):
            await async_client.fine_tuning_jobs.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.list()
        assert_matches_type(AsyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.list(
            account_id="account_id",
            limit=1,
            page=1,
        )
        assert_matches_type(AsyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.fine_tuning_jobs.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = await response.parse()
        assert_matches_type(AsyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.fine_tuning_jobs.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = await response.parse()
            assert_matches_type(AsyncPageResponse[FineTuningJob], fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncSGPClient) -> None:
        fine_tuning_job = await async_client.fine_tuning_jobs.delete(
            "fine_tuning_job_id",
        )
        assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.fine_tuning_jobs.with_raw_response.delete(
            "fine_tuning_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        fine_tuning_job = await response.parse()
        assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSGPClient) -> None:
        async with async_client.fine_tuning_jobs.with_streaming_response.delete(
            "fine_tuning_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            fine_tuning_job = await response.parse()
            assert_matches_type(GenericDeleteResponse, fine_tuning_job, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `fine_tuning_job_id` but received ''"):
            await async_client.fine_tuning_jobs.with_raw_response.delete(
                "",
            )



### manual_evaluation_dataset_creation_example_script.py ###
# This script demonstrates how to create a manual evaluation dataset
# For manual evaluation datasets, all test cases are uploaded manually, with input, expected_output, and expected_extra_info fields
# Evaluation datasets, once published, can be used for application variant runs and report card generation

import os

from scale_gp import SGPClient

account_id = os.environ.get("SGP_ACCOUNT_ID", None)
api_key = os.environ.get("SGP_API_KEY", None)

assert (
    account_id is not None
), "You need to set the SGP_ACCOUNT_ID - you can find it at https://egp.dashboard.scale.com/admin/accounts"
assert api_key is not None, "You need to provide your API key - see https://egp.dashboard.scale.com/admin/api-key"

# Create an SGP Client
client = SGPClient(api_key=api_key)

### manual evaluation dataset ###
DATASET = [
    {
        "input": "What is the capital of France?",
        "expected_output": "The capital of France is Paris.",
        "expected_extra_info": {
            "info": "Paris, located in the northern part of France along the Seine River, is not only the country’s capital but also its largest city. Known for its art, fashion, gastronomy, and culture, Paris has a significant influence both in France and globally.",
            "schema_type": "STRING",
        },
    },
    {
        "input": "What color is an apple?",
        "expected_output": "An apple is typically red when ripe, though green and yellow varieties also exist depending on the species and maturity.",
        "expected_extra_info": {
            "info": "Apples come in various colors including red, green, and yellow. Red apples are one of the most common, with varieties like Red Delicious being very popular. Green apples, like Granny Smith, are tart and used often in baking. Yellow apples such as Golden Delicious are sweet and softer.",
            "schema_type": "STRING",
        },
    },
    {
        "input": "Who is the first president of the USA?",
        "expected_output": "The first president of the USA is George Washington.",
        "expected_extra_info": {
            "info": "George Washington served as the first president of the United States from 1789 to 1797. He is a pivotal figure in American history, recognized for his leadership during the Revolutionary War and setting many precedents for the national government.",
            "schema_type": "STRING",
        },
    },
]

# create evaluation dataset to contain your test cases
manual_evaluation_dataset = client.evaluation_datasets.create(
    account_id=account_id,
    name="manual_evaluation_dataset",
    schema_type="GENERATION",
    type="manual",
)

# iteratively upload test cases
test_cases = []
for test_case in DATASET:
    uploaded_test_case = client.evaluation_datasets.test_cases.create(
        account_id=account_id,
        evaluation_dataset_id=manual_evaluation_dataset.id,
        test_case_data=test_case,
    )
    test_cases.append(uploaded_test_case)

# alternatively you can use batching for faster uploads
uploaded_test_cases = client.evaluation_datasets.test_cases.batch(
    evaluation_dataset_id=manual_evaluation_dataset.id,
    items=[{"account_id": account_id, "schema_type": "GENERATION", "test_case_data": item} for item in DATASET],
)
test_cases.extend(uploaded_test_cases)

# snapshot into a dataset version
manual_dataset_version = client.evaluation_datasets.evaluation_dataset_versions.create(
    evaluation_dataset_id=manual_evaluation_dataset.id
)

# publish the dataset. datasets must be published before they can be used in evaluations.
published_dataset_response = client.evaluation_datasets.publish(
    evaluation_dataset_id=manual_evaluation_dataset.id,
)

print("Published manual evaluation dataset with id:", manual_evaluation_dataset.id)
print(manual_dataset_version)

test_cases = client.evaluation_datasets.test_cases.list(
    evaluation_dataset_id=manual_evaluation_dataset.id, account_id=account_id
)

print("Created the following test cases:")
print(test_cases.items)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["StringExtraInfoSchema"]


class StringExtraInfoSchema(TypedDict, total=False):
    info: Required[str]

    schema_type: Literal["STRING"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Annotated, TypeAlias

from ..._utils import PropertyInfo
from ..._models import BaseModel
from .flexible_chunk import FlexibleChunk
from .flexible_message import FlexibleMessage
from ..shared.chunk_extra_info_schema import ChunkExtraInfoSchema
from ..shared.string_extra_info_schema import StringExtraInfoSchema

__all__ = ["FlexibleTestCaseSchema", "ExpectedExtraInfo"]

ExpectedExtraInfo: TypeAlias = Annotated[
    Union[ChunkExtraInfoSchema, StringExtraInfoSchema], PropertyInfo(discriminator="schema_type")
]


class FlexibleTestCaseSchema(BaseModel):
    input: Union[
        str,
        float,
        List[FlexibleChunk],
        List[FlexibleMessage],
        List[object],
        Dict[str, Union[str, float, List[FlexibleChunk], List[FlexibleMessage], List[object], object]],
        object,
    ]

    expected_extra_info: Optional[ExpectedExtraInfo] = None

    expected_output: Union[
        str,
        float,
        List[FlexibleChunk],
        List[FlexibleMessage],
        List[object],
        Dict[str, Union[str, float, List[FlexibleChunk], List[FlexibleMessage], List[object], object]],
        object,
        None,
    ] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .contents import (
    ContentsResource,
    AsyncContentsResource,
    ContentsResourceWithRawResponse,
    AsyncContentsResourceWithRawResponse,
    ContentsResourceWithStreamingResponse,
    AsyncContentsResourceWithStreamingResponse,
)
from .training_datasets import (
    TrainingDatasetsResource,
    AsyncTrainingDatasetsResource,
    TrainingDatasetsResourceWithRawResponse,
    AsyncTrainingDatasetsResourceWithRawResponse,
    TrainingDatasetsResourceWithStreamingResponse,
    AsyncTrainingDatasetsResourceWithStreamingResponse,
)

__all__ = [
    "ContentsResource",
    "AsyncContentsResource",
    "ContentsResourceWithRawResponse",
    "AsyncContentsResourceWithRawResponse",
    "ContentsResourceWithStreamingResponse",
    "AsyncContentsResourceWithStreamingResponse",
    "TrainingDatasetsResource",
    "AsyncTrainingDatasetsResource",
    "TrainingDatasetsResourceWithRawResponse",
    "AsyncTrainingDatasetsResourceWithRawResponse",
    "TrainingDatasetsResourceWithStreamingResponse",
    "AsyncTrainingDatasetsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, TypeAlias, TypedDict

from .flexible_test_case_schema_param import FlexibleTestCaseSchemaParam
from .artifact_schema_generation_param import ArtifactSchemaGenerationParam
from .generation_test_case_schema_param import GenerationTestCaseSchemaParam

__all__ = [
    "TestCaseUpdateParams",
    "PartialTestCaseVersionRequest",
    "PartialTestCaseVersionRequestTestCaseData",
    "RestoreRequest",
]


class PartialTestCaseVersionRequest(TypedDict, total=False):
    evaluation_dataset_id: Required[str]

    chat_history: object
    """Used for tracking previous chat interactions for multi-chat test cases"""

    restore: Literal[False]
    """Set to true to restore the entity from the database."""

    test_case_data: PartialTestCaseVersionRequestTestCaseData
    """The data for the test case in a format matching the provided schema_type"""

    test_case_metadata: object
    """Metadata for the test case"""


PartialTestCaseVersionRequestTestCaseData: TypeAlias = Union[
    ArtifactSchemaGenerationParam, GenerationTestCaseSchemaParam, FlexibleTestCaseSchemaParam
]


class RestoreRequest(TypedDict, total=False):
    evaluation_dataset_id: Required[str]

    restore: Required[Literal[True]]
    """Set to true to restore the entity from the database."""


TestCaseUpdateParams: TypeAlias = Union[PartialTestCaseVersionRequest, RestoreRequest]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["S3DataSourceConfig"]


class S3DataSourceConfig(BaseModel):
    aws_account_id: str
    """AWS account ID that owns the S3 bucket."""

    aws_region: str
    """AWS region where the S3 bucket is located."""

    s3_bucket: str
    """Name of the S3 bucket where the data is stored."""

    source: Literal["S3"]

    s3_prefix: Optional[str] = None
    """Prefix of the S3 bucket where the data is stored.

    If not specified, the entire bucket will be used.
    """
